==> dokuwiki_0.0.20140505.a+dfsg.orig.tar.gz: dokuwiki-2014-05-05a/lib/plugins/extension/lang/eo/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Robert Bogenschneider <bogi@uea.org>
 */
$lang['menu']                  = 'Aldonaĵa administrado';
$lang['tab_plugins']           = 'Instalitaj kromaĵoj';
$lang['tab_templates']         = 'Instalitaj ŝablonoj';
$lang['tab_search']            = 'Serĉi kaj instali';
$lang['tab_install']           = 'Permana instalado';
$lang['notimplemented']        = 'Tiu funkcio ankoraŭ ne realiĝis';
$lang['notinstalled']          = 'Tiu aldonaĵo ne estas instalita';
$lang['alreadyenabled']        = 'Tiu aldonaĵo jam ebliĝis';
$lang['alreadydisabled']       = 'Tiu aldonaĵo jam malebliĝis';
$lang['pluginlistsaveerror']   = 'Okazis eraro dum la kromaĵlisto konserviĝis';
$lang['unknownauthor']         = 'Nekonata aŭtoro';
$lang['unknownversion']        = 'Nekonata versio';
$lang['btn_info']              = 'Montri pliajn informojn';
$lang['btn_update']            = 'Aktualigi';
$lang['btn_uninstall']         = 'Malinstali';
$lang['btn_enable']            = 'Ebligi';
$lang['btn_disable']           = 'Malebligi';
$lang['btn_install']           = 'Instali';
$lang['btn_reinstall']         = 'Re-instali';
$lang['js']['reallydel']       = 'Ĉu vere malinstali la aldonaĵon?';
$lang['search_for']            = 'Serĉi la aldonaĵon:';
$lang['search']                = 'Serĉi';
$lang['extensionby']           = '<strong>%s</strong> fare de %s';
$lang['screenshot']            = 'Ekrankopio de %s';
$lang['popularity']            = 'Populareco: %s%%';
$lang['homepage_link']         = 'Dokumentoj';
$lang['bugs_features']         = 'Cimoj';
$lang['tags']                  = 'Etikedoj:';
$lang['author_hint']           = 'Serĉi aldonaĵojn laŭ tiu aŭtoro:';
$lang['installed']             = 'Instalitaj:';
$lang['downloadurl']           = 'URL por elŝuti:';
$lang['repository']            = 'Kodbranĉo:';
$lang['unknown']               = '<em>nekonata</em>';
$lang['installed_version']     = 'Instalita versio:';
$lang['install_date']          = 'Via lasta aktualigo:';
$lang['available_version']     = 'Havebla versio:';
$lang['compatible']            = 'Kompatibla kun:';
$lang['depends']               = 'Dependas de:';
$lang['similar']               = 'Simila al:';
$lang['conflicts']             = 'Konfliktas kun:';
$lang['donate']                = 'Ĉu vi ŝatas tion?';
$lang['donate_action']         = 'Aĉetu kafon al la aŭtoro!';
$lang['repo_retry']            = 'Reprovi';
$lang['provides']              = 'Provizas per:';
$lang['status']                = 'Statuso:';
$lang['status_installed']      = 'instalita';
$lang['status_not_installed']  = 'ne instalita';
$lang['status_protected']      = 'protektita';
$lang['status_enabled']        = 'ebligita';
$lang['status_disabled']       = 'malebligita';
$lang['status_unmodifiable']   = 'neŝanĝebla';
$lang['status_plugin']         = 'kromaĵo';
$lang['status_template']       = 'ŝablono';
$lang['status_bundled']        = 'kunliverita';
$lang['msg_enabled']           = 'Kromaĵo %s ebligita';
$lang['msg_disabled']          = 'Kromaĵo %s malebligita';
$lang['msg_delete_success']    = 'Aldonaĵo malinstaliĝis';
$lang['msg_template_install_success'] = 'Ŝablono %s sukcese instaliĝis';
$lang['msg_template_update_success'] = 'Ŝablono %s sukcese aktualiĝis';
$lang['msg_plugin_install_success'] = 'Kromaĵo %s sukcese instaliĝis';
$lang['msg_plugin_update_success'] = 'Kromaĵo %s sukcese aktualiĝis';
$lang['msg_upload_failed']     = 'Ne eblis alŝuti la dosieron';
$lang['missing_dependency']    = '<strong>Mankanta aŭ malebligita dependeco:</strong> %s';
$lang['security_issue']        = '<strong>Sekureca problemo:</strong> %s';
$lang['security_warning']      = '<strong>Sekureca averto:</strong> %s';
$lang['update_available']      = '<strong>Aktualigo:</strong> Nova versio %s haveblas.';
$lang['wrong_folder']          = '<strong>Kromaĵo instalita malĝuste:</strong> Renomu la kromaĵdosierujon "%s" al "%s".';
$lang['url_change']            = '<strong>URL ŝanĝita:</strong> La elŝuta URL ŝanĝiĝis ekde la lasta elŝuto. Kontrolu, ĉu la nova URL validas antaŭ aktualigi aldonaĵon.<br />Nova: %s<br />Malnova: %s';
$lang['error_badurl']          = 'URLoj komenciĝu per http aŭ https';
$lang['error_dircreate']       = 'Ne eblis krei portempan dosierujon por akcepti la elŝuton';
$lang['error_download']        = 'Ne eblis elŝuti la dosieron: %s';
$lang['error_decompress']      = 'Ne eblis malpaki la elŝutitan dosieron. Kialo povus esti fuŝa elŝuto, kaj vi reprovu; aŭ la pakiga formato estas nekonata, kaj vi devas elŝuti kaj instali permane.';
$lang['error_findfolder']      = 'Ne eblis rekoni la aldonaĵ-dosierujon, vi devas elŝuti kaj instali permane';
$lang['error_copy']            = 'Okazis kopiad-eraro dum la provo instali dosierojn por la dosierujo <em>%s</em>: la disko povus esti plena aŭ la alirpermesoj por dosieroj malĝustaj. Rezulto eble estas nur parte instalita kromaĵo, kiu malstabiligas vian vikion';
$lang['noperms']               = 'La aldonaĵ-dosierujo ne estas skribebla';
$lang['notplperms']            = 'La ŝablon-dosierujo ne estas skribebla';
$lang['nopluginperms']         = 'La kromaĵ-dosierujo ne estas skribebla';
$lang['git']                   = 'Tiu aldonaĵo estis instalita pere de git, eble vi ne aktualigu ĝin ĉi tie.';
$lang['install_url']           = 'Instali de URL:';
$lang['install_upload']        = 'Alŝuti aldonaĵon:';

==> dokuwiki_0.0.20220731.a.orig.tar.gz: dokuwiki-2022-07-31a/lib/plugins/extension/lang/eo/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Kristjan SCHMIDT <kristjan.schmidt@googlemail.com>
 * @author Robert Bogenschneider <bogi@uea.org>
 */
$lang['menu']                  = 'Aldonaĵa administrado';
$lang['tab_plugins']           = 'Instalitaj kromaĵoj';
$lang['tab_templates']         = 'Instalitaj ŝablonoj';
$lang['tab_search']            = 'Serĉi kaj instali';
$lang['tab_install']           = 'Permana instalado';
$lang['notimplemented']        = 'Tiu funkcio ankoraŭ ne realiĝis';
$lang['notinstalled']          = 'Tiu aldonaĵo ne estas instalita';
$lang['alreadyenabled']        = 'Tiu aldonaĵo jam ebliĝis';
$lang['alreadydisabled']       = 'Tiu aldonaĵo jam malebliĝis';
$lang['pluginlistsaveerror']   = 'Okazis eraro dum la kromaĵlisto konserviĝis';
$lang['unknownauthor']         = 'Nekonata aŭtoro';
$lang['unknownversion']        = 'Nekonata versio';
$lang['btn_info']              = 'Montri pliajn informojn';
$lang['btn_update']            = 'Aktualigi';
$lang['btn_uninstall']         = 'Malinstali';
$lang['btn_enable']            = 'Ebligi';
$lang['btn_disable']           = 'Malebligi';
$lang['btn_install']           = 'Instali';
$lang['btn_reinstall']         = 'Re-instali';
$lang['js']['reallydel']       = 'Ĉu vere malinstali la aldonaĵon?';
$lang['js']['display_updatable'] = 'ĝisdatigebla';
$lang['search_for']            = 'Serĉi la aldonaĵon:';
$lang['search']                = 'Serĉi';
$lang['extensionby']           = '<strong>%s</strong> fare de %s';
$lang['screenshot']            = 'Ekrankopio de %s';
$lang['popularity']            = 'Populareco: %s%%';
$lang['homepage_link']         = 'Dokumentoj';
$lang['bugs_features']         = 'Cimoj';
$lang['tags']                  = 'Etikedoj:';
$lang['author_hint']           = 'Serĉi aldonaĵojn laŭ tiu aŭtoro:';
$lang['installed']             = 'Instalitaj:';
$lang['downloadurl']           = 'URL por elŝuti:';
$lang['repository']            = 'Kodbranĉo:';
$lang['unknown']               = '<em>nekonata</em>';
$lang['installed_version']     = 'Instalita versio:';
$lang['install_date']          = 'Via lasta aktualigo:';
$lang['available_version']     = 'Havebla versio:';
$lang['compatible']            = 'Kompatibla kun:';
$lang['depends']               = 'Dependas de:';
$lang['similar']               = 'Simila al:';
$lang['conflicts']             = 'Konfliktas kun:';
$lang['donate']                = 'Ĉu vi ŝatas tion?';
$lang['donate_action']         = 'Aĉetu kafon al la aŭtoro!';
$lang['repo_retry']            = 'Reprovi';
$lang['provides']              = 'Provizas per:';
$lang['status']                = 'Statuso:';
$lang['status_installed']      = 'instalita';
$lang['status_not_installed']  = 'ne instalita';
$lang['status_protected']      = 'protektita';
$lang['status_enabled']        = 'ebligita';
$lang['status_disabled']       = 'malebligita';
$lang['status_unmodifiable']   = 'neŝanĝebla';
$lang['status_plugin']         = 'kromaĵo';
$lang['status_template']       = 'ŝablono';
$lang['status_bundled']        = 'kunliverita';
$lang['msg_enabled']           = 'Kromaĵo %s ebligita';
$lang['msg_disabled']          = 'Kromaĵo %s malebligita';
$lang['msg_delete_success']    = 'Aldonaĵo %s malinstaliĝis';
$lang['msg_template_install_success'] = 'Ŝablono %s sukcese instaliĝis';
$lang['msg_template_update_success'] = 'Ŝablono %s sukcese aktualiĝis';
$lang['msg_plugin_install_success'] = 'Kromaĵo %s sukcese instaliĝis';
$lang['msg_plugin_update_success'] = 'Kromaĵo %s sukcese aktualiĝis';
$lang['msg_upload_failed']     = 'Ne eblis alŝuti la dosieron';
$lang['missing_dependency']    = '<strong>Mankanta aŭ malebligita dependeco:</strong> %s';
$lang['security_issue']        = '<strong>Sekureca problemo:</strong> %s';
$lang['security_warning']      = '<strong>Sekureca averto:</strong> %s';
$lang['update_available']      = '<strong>Aktualigo:</strong> Nova versio %s haveblas.';
$lang['wrong_folder']          = '<strong>Kromaĵo instalita malĝuste:</strong> Renomu la kromaĵdosierujon "%s" al "%s".';
$lang['url_change']            = '<strong>URL ŝanĝita:</strong> La elŝuta URL ŝanĝiĝis ekde la lasta elŝuto. Kontrolu, ĉu la nova URL validas antaŭ aktualigi aldonaĵon.<br />Nova: %s<br />Malnova: %s';
$lang['error_badurl']          = 'URLoj komenciĝu per http aŭ https';
$lang['error_dircreate']       = 'Ne eblis krei portempan dosierujon por akcepti la elŝuton';
$lang['error_download']        = 'Ne eblis elŝuti la dosieron: %s';
$lang['error_decompress']      = 'Ne eblis malpaki la elŝutitan dosieron. Kialo povus esti fuŝa elŝuto, kaj vi reprovu; aŭ la pakiga formato estas nekonata, kaj vi devas elŝuti kaj instali permane.';
$lang['error_findfolder']      = 'Ne eblis rekoni la aldonaĵ-dosierujon, vi devas elŝuti kaj instali permane';
$lang['error_copy']            = 'Okazis kopiad-eraro dum la provo instali dosierojn por la dosierujo <em>%s</em>: la disko povus esti plena aŭ la alirpermesoj por dosieroj malĝustaj. Rezulto eble estas nur parte instalita kromaĵo, kiu malstabiligas vian vikion';
$lang['noperms']               = 'La aldonaĵ-dosierujo ne estas skribebla';
$lang['notplperms']            = 'La ŝablon-dosierujo ne estas skribebla';
$lang['nopluginperms']         = 'La kromaĵ-dosierujo ne estas skribebla';
$lang['git']                   = 'Tiu aldonaĵo estis instalita pere de git, eble vi ne aktualigu ĝin ĉi tie.';
$lang['install_url']           = 'Instali de URL:';
$lang['install_upload']        = 'Alŝuti aldonaĵon:';
